@@ -1,21 +1,20 @@
 #' @title labelSample
 #'
-#' @description {Pixel-based labeling of spatially connected groups of samples for splitting them between training and validation.}
-#' @param xy Object of class \emph{SpatialPoints} of \emph{SpatialPointsDataFrame}.
+#' @description {Pixel-based labeling of spatially connected groups of points in a \emph{SpatialPoints} object.}
+#' @param x Object of class \emph{SpatialPoints} of \emph{SpatialPointsDataFrame}.
+#' @param y Pixel resolution or a valid raster layer.
 #' @param agg.radius Minimum radius for pixel aggregation. Unit depends on the projection of the data.
-#' @param nr.points Minimum number of samples per pixel.
+#' @param nr.points Minimum number of observations per pixel.
 #' @param nr.pixels Minimum number of pixels per region.
-#' @param pixel.res Pixel resolution or a valid raster layer.
 #' @references \href{10.1002/rse2.70}{Remelgado, R., Leutner, B., Safi, K., Sonnenschein, R., Kuebert, C. and Wegmann, M. (2017), Linking animal movement and remote sensing - mapping resource suitability from a remote sensing perspective. Remote Sens Ecol Conserv.}
-#' @return A \emph{vector} of unique identifiers assigning each point in \emph{xy} to their correspondent pixel region. Filtered observations are returned as \emph{NA}.
-#' @details {First, the samples are converted to pixel coordinates and removes pixels with a corresponding number of points greater
-#' than \emph{nr.points}. Then, if \emph{nr.pixels} is set, the connectivity between neighboring samples is evaluated. Internally, the
-#' function will label groups of pixels based on their connectivity and regions with a pixel count smaller than the one specified by
-#' \emph{nr.pixels} are excluded. Then, the algorithm aggregates nearby regions using a dilation algorithm within the radius specified
-#' by \emph{agg.radius} and proceeds to reliable the pixels covered by samples. Finally, this information is used to label the original
-#' samples provided by \emph{xy} based on their corresponding pixel coordinates. This analysis is based on the spatial extent of \emph{xy}
-#' and a given pixel resolution (\emph{pixel.res}). Alternatively, the user may assign a raster object to \emph{pixel.res}.}
-#' @importFrom raster crs cellFromXY extent raster res freq clump rowFromCell colFromCell
+#' @return A numeric \emph{vector} with region identifiers for each observation in \emph{x} to their correspondent pixel region. Filtered observations are returned as \emph{NA}.
+#' @details {First, the observations are converted to pixel coordinates and pixels with a corresponding number of observations greater than \emph{nr.points}
+#' are filtered out. Then, if \emph{nr.pixels} is set, the function evaluates the spatial connectivity of the pixels and regions with a pixel count smaller
+#' than \emph{nr.pixels} are filtered out. Then, the algorithm aggregates nearby regions within the distance specified by \emph{agg.radius}. The final region
+#' identifiers are then assigned back to the original observations in \emph{x} based on their corresponding pixel coordinates. This analysis is based on the spatial
+#' extent of \emph{x} and a given pixel resolution (\emph{y}). Alternatively, the user may assign a raster object as \emph{y} assuring that the
+#' final output is aligned with it.}
+#' @importFrom raster crs cellFromXY extent raster res freq clump rowFromCell colFromCell focal
 #' @seealso \code{\link{sampleMove}} \code{\link{hotMove}}
 #' @examples {
 #'
@@ -35,16 +34,15 @@
 
 #---------------------------------------------------------------------------------------------------------------------------------------------#
 
-labelSample <- function(xy, pixel.res, agg.radius=NULL, nr.points=NULL, nr.pixels=NULL) {
+labelSample <- function(x, y, nr.points=1, nr.pixels=NULL, agg.radius=NULL) {
 
 #--------------------------------------------------------------------------------------------------------------------------------------------#
 # 1. check input variables
 #--------------------------------------------------------------------------------------------------------------------------------------------#
 
   # check input variables
-  if (!exists('xy')) {stop('"xy" is missing')}
-  if (!class(xy)[1]%in%c('SpatialPoints', 'SpatialPointsDataFrame')) {stop('"xy" is not of a valid class')}
-  if (is.null(crs(xy)@projargs)) {stop('"xy" is missing a valid projection')}
+  if (!class(x)[1]%in%c('SpatialPoints', 'SpatialPointsDataFrame')) {stop('"x" is not of a valid class')}
+  if (is.null(crs(x)@projargs)) {stop('"x" is missing a valid projection')}
   if (!is.null(nr.pixels)) {if (!is.numeric(nr.pixels) | length(nr.pixels)!=1) {stop('"nr.pixels" is not a valid input')}}
   if (!is.null(nr.points)) {if (!is.numeric(nr.points) | length(nr.points)!=1) {stop('"nr.points" is not a valid input')}}
   if (!is.null(agg.radius)) {if (!is.numeric(agg.radius) | length(agg.radius)!=1) {stop('"agg.radius" is not a valid input')}}
@@ -54,24 +52,24 @@ labelSample <- function(xy, pixel.res, agg.radius=NULL, nr.points=NULL, nr.pixel
 #--------------------------------------------------------------------------------------------------------------------------------------------#
 
   # build sample mask (from extent)
-  if (is.numeric(pixel.res)) {
-    ext <- extent(xy)
-    pixel.res <- raster(ext, res=pixel.res, crs=crs(xy), vals=NA)
-    sp <- cellFromXY(pixel.res, xy)
+  if (is.numeric(y)) {
+    ext <- extent(x)
+    y <- raster(ext, res=y, crs=crs(x), vals=NA)
+    sp <- cellFromXY(y, x)
     up <- unique(sp)
     up <- up[!is.na(up)]
-    pixel.res[up] <- 1}
+    y[up] <- 1}
 
   # build sample mask (from raster)
-  if (class(pixel.res)[1]%in%c('RasterLayer', 'RasterStack', 'RasterBrick')) {
-    if (crs(xy)@projargs!=crs(pixel.res)@projargs) {stop('"xy" and "pixel.res" have different projections')}
-    sp <- cellFromXY(pixel.res, xy@coords)
+  if (class(y)[1]%in%c('RasterLayer', 'RasterStack', 'RasterBrick')) {
+    if (crs(x)@projargs!=crs(y)@projargs) {stop('"x" and "y" have different projections')}
+    sp <- cellFromXY(y, x@coords)
     up <- unique(sp)
     up <- up[!is.na(up)]
-    pixel.res <- raster(extent(pixel.res), res=res(pixel.res), crs=crs(pixel.res), vals=NA)
-    pixel.res[up] <- 1}
+    y <- raster(extent(y), res=res(y), crs=crs(y), vals=NA)
+    y[up] <- 1}
 
-  if (length(up)==1) {stop('warning: only one pixel in the data. Processing aborted (is pixel.res correct?)')}
+  if (length(up)==1) {stop('warning: only one pixel in the data. Processing aborted (is y correct?)')}
 
   #--------------------------------------------------------------------------------------------------------------------------------------------#
   # 3. region label (phase I)
@@ -79,19 +77,19 @@ labelSample <- function(xy, pixel.res, agg.radius=NULL, nr.points=NULL, nr.pixel
 
   # filter based on the number of pixels
   if (!is.null(nr.points)) {
-    count <- sapply(up, function(x) {sum(sp==x)})
+    count <- sapply(up, function(i) {sum(sp==i)})
     up <- up[which(count >= nr.points)]
     rm(count)}
 
   # filter samples based on the size of pixel groups
   if (!is.null(nr.pixels)) {
-    regions <- clump(pixel.res)
+    regions <- clump(y)
     px.freq <- freq(regions,useNA="no")
     ind <- which(px.freq[,2] < nr.pixels)
     ind <- as.vector(px.freq[ind,1])
-    if (!is.na(ind[1])) {for (i in 1:length(ind)) {pixel.res[regions==ind[i]] <- 0}}
+    if (!is.na(ind[1])) {for (i in 1:length(ind)) {y[regions==ind[i]] <- NA}}
     rm(regions, px.freq, ind)
-    up <- up[pixel.res[up] > 0]}
+    up <- up[y[up] > 0]}
 
   # control sample amountth
   if (length(up)==0) {stop(paste0('there are no regions with >= ', as.character(nr.pixels), ' pixels. Consider reducing "nr.pixels"'))}
@@ -101,28 +99,20 @@ labelSample <- function(xy, pixel.res, agg.radius=NULL, nr.points=NULL, nr.pixel
   #--------------------------------------------------------------------------------------------------------------------------------------------#
 
   #determine radius (in pixels)
-  agg.radius <- round((agg.radius/res(pixel.res)[1])+0.1)
+  agg.radius <- (round((agg.radius/res(y)[1])+0.1)*2) + 1
 
   # dilate samples
   if (agg.radius > 0) {
-
-    for (p in 1:length(up)) {
-
-      rp <- rowFromCell(pixel.res, up[p]) # row position
-      cp <- colFromCell(pixel.res, up[p]) # column positon
-      pixel.res[(rp-agg.radius):(rp+agg.radius), (cp-agg.radius):(cp+agg.radius)] <- 1
-
-    }
-
-  }
+    y <- focal(y, matrix(0,agg.radius, agg.radius), function(j) {sum(!is.na(j))}, pad=TRUE, padValue=NA) > 0
+    y[y == 0] <- NA}
 
   # evaluate sample connectivity
-  pixel.res <- clump(pixel.res)
+  y <- clump(y)
 
   #--------------------------------------------------------------------------------------------------------------------------------------------#
   # 5. return ID's
   #--------------------------------------------------------------------------------------------------------------------------------------------#
 
-  return(pixel.res[sp])
+  return(y[sp])
 
 }
